@@ -1,10 +1,8 @@
+use async_io;
 use netscan::result::{ScanStatus, PortStatus, PortScanResult, HostScanResult};
 use netscan::setting::Destination;
 use netscan::blocking::{PortScanner, HostScanner};
-
-#[cfg(not(target_os="windows"))]
 use netscan::async_io::{PortScanner as AsyncPortScanner, HostScanner as AsyncHostScanner};
-
 use netscan::service::{ServiceDetector, PortDatabase};
 use crossterm::style::Colorize;
 use std::io::{stdout, Write};
@@ -18,19 +16,21 @@ use crate::network;
 use crate::result::{PortInfo, PortResult, HostInfo, HostResult};
 use crate::printer;
 
-pub async fn handle_port_scan(opt: option::PortOption) {
+pub fn handle_port_scan(opt: option::PortOption) {
     let mut port_info_list: Vec<PortInfo> = vec![];
     printer::print_port_option(opt.clone());
     print!("Checking interface... ");
     stdout().flush().unwrap();
     let src_ip: IpAddr = if opt.src_ip.is_empty() {
         let default_if = default_net::get_default_interface().expect("");
-        IpAddr::V4(default_if.ipv4[0]) 
+        IpAddr::V4(default_if.ipv4[0].addr) 
     }else{
         opt.src_ip.parse::<IpAddr>().expect("")
     };
     println!("{}", "Done".green());
-    let result: PortScanResult = scan_ports(src_ip, opt.clone()).await;
+    let result: PortScanResult = async_io::block_on(async {
+        scan_ports(src_ip, opt.clone()).await
+    });
     match result.scan_status {
         ScanStatus::Done => println!("{}", "Done".green()),
         ScanStatus::Timeout => println!("{}", "Timed out".yellow()),
@@ -131,19 +131,21 @@ pub async fn handle_port_scan(opt: option::PortOption) {
     }
 }
 
-pub async fn handle_host_scan(opt: option::HostOption) {
+pub fn handle_host_scan(opt: option::HostOption) {
     let mut host_info_list: Vec<HostInfo> = vec![];
     printer::print_host_option(opt.clone());
     print!("Checking interface... ");
     stdout().flush().unwrap();
     let src_ip: IpAddr = if opt.src_ip.is_empty() {
         let default_if = default_net::get_default_interface().expect("");
-        IpAddr::V4(default_if.ipv4[0]) 
+        IpAddr::V4(default_if.ipv4[0].addr) 
     }else{
         opt.src_ip.parse::<IpAddr>().expect("")
     };
     println!("{}", "Done".green());
-    let result: HostScanResult = scan_hosts(src_ip, opt.clone()).await;
+    let result: HostScanResult = async_io::block_on(async {
+        scan_hosts(src_ip, opt.clone()).await
+    });
     match result.scan_status {
         ScanStatus::Done => {println!("{}", "Done".green())},
         ScanStatus::Timeout => {println!("{}", "Timed out".yellow())},
@@ -183,7 +185,6 @@ pub async fn handle_host_scan(opt: option::HostOption) {
         },
     }
     let mut os_map: HashMap<IpAddr, (String, String)> = HashMap::new();
-    let ttl_map: HashMap<u8, String> = db::get_os_ttl();
     if opt.os_detection {
         print!("Detecting OS... ");
         stdout().flush().unwrap();
@@ -194,9 +195,7 @@ pub async fn handle_host_scan(opt: option::HostOption) {
         os_map = probe::os::default_os_fingerprinting(src_ip, hosts);
         if os_map.len() == 0 {
             for host in result.hosts.clone() {
-                let ini_ttl: u8 = probe::os::guess_initial_ttl(host.ttl);
-                let os_name: String = ttl_map.get(&ini_ttl).unwrap_or(&String::new()).to_string();
-                os_map.insert(host.ip_addr, (os_name,String::new()));
+                os_map.insert(host.ip_addr, (String::from("Unknown"), String::from("Unknown")));
             }
             println!("{}", "Failed".red());
         }else {
@@ -204,9 +203,7 @@ pub async fn handle_host_scan(opt: option::HostOption) {
         }
     }else{
         for host in result.hosts.clone() {
-            let ini_ttl: u8 = probe::os::guess_initial_ttl(host.ttl);
-            let os_name: String = ttl_map.get(&ini_ttl).unwrap_or(&String::new()).to_string();
-            os_map.insert(host.ip_addr, (os_name,String::new()));
+            os_map.insert(host.ip_addr, (String::from("Unknown"), String::from("Unknown")));
         }
     }
     for host in result.hosts {
@@ -240,7 +237,6 @@ pub async fn handle_host_scan(opt: option::HostOption) {
     }
 }
 
-#[cfg(not(target_os="windows"))]
 async fn scan_ports(src_ip: IpAddr, opt: option::PortOption) -> PortScanResult {
     if opt.async_scan {
         let mut port_scanner = match AsyncPortScanner::new(src_ip){
@@ -277,26 +273,6 @@ async fn scan_ports(src_ip: IpAddr, opt: option::PortOption) -> PortScanResult {
     }
 }
 
-#[cfg(target_os="windows")]
-async fn scan_ports(src_ip: IpAddr, opt: option::PortOption) -> PortScanResult {
-    let mut port_scanner = match PortScanner::new(src_ip){
-        Ok(scanner) => (scanner),
-        Err(e) => panic!("Error creating scanner: {}", e),
-    };
-    let dst: Destination = Destination::new(opt.dst_ip_addr.parse::<IpAddr>().unwrap(), opt.dst_ports);
-    port_scanner.add_destination(dst);
-    port_scanner.set_scan_type(opt.scan_type);
-    port_scanner.set_timeout(opt.timeout);
-    port_scanner.set_wait_time(opt.wait_time);
-    port_scanner.set_send_rate(opt.send_rate);
-    print!("Scanning... ");
-    stdout().flush().unwrap();
-    port_scanner.run_scan();
-    let result: PortScanResult = port_scanner.get_scan_result();
-    return result;
-}
-
-#[cfg(not(target_os="windows"))]
 async fn scan_hosts(src_ip: IpAddr, opt: option::HostOption) -> HostScanResult {
     if opt.async_scan {
         let mut host_scanner = match AsyncHostScanner::new(src_ip){
@@ -334,23 +310,3 @@ async fn scan_hosts(src_ip: IpAddr, opt: option::HostOption) -> HostScanResult {
         return result;
     }
 }
-
-#[cfg(target_os="windows")]
-async fn scan_hosts(src_ip: IpAddr, opt: option::HostOption) -> HostScanResult {
-    let mut host_scanner = match HostScanner::new(src_ip){
-        Ok(scanner) => (scanner),
-        Err(e) => panic!("Error creating scanner: {}", e),
-    };
-    for host in opt.dst_hosts {
-        let dst: Destination = Destination::new(host.parse::<IpAddr>().unwrap(), vec![]);
-        host_scanner.add_destination(dst);
-    }
-    host_scanner.set_timeout(opt.timeout);
-    host_scanner.set_wait_time(opt.wait_time);
-    host_scanner.set_send_rate(opt.send_rate);
-    print!("Scanning... ");
-    stdout().flush().unwrap();
-    host_scanner.run_scan();
-    let result: HostScanResult = host_scanner.get_scan_result();
-    return result;
-}
