@@ -1,9 +1,8 @@
 use std::net::IpAddr;
-use pnet::datalink;
 
 #[allow(dead_code)]
 pub fn get_interface_index_by_name(if_name: String) -> Option<u32> {
-    for iface in datalink::interfaces() {
+    for iface in pnet_datalink::interfaces() {
         if iface.name == if_name {
             return Some(iface.index)
         }
@@ -12,7 +11,7 @@ pub fn get_interface_index_by_name(if_name: String) -> Option<u32> {
 }
 
 pub fn get_interface_index_by_ip(ip_addr: IpAddr) -> Option<u32> {
-    for iface in datalink::interfaces() {
+    for iface in pnet_datalink::interfaces() {
         for ip in iface.ips {
             if ip.ip() == ip_addr {
                 return Some(iface.index);
